[![DOI](https://joss.theoj.org/papers/10.21105/joss.05526/status.svg)](https://doi.org/10.21105/joss.05526)
[![DOI](https://zenodo.org/badge/553182204.svg)](https://zenodo.org/badge/latestdoi/553182204) 
![coverage](bayes_toolbox/tests/coverage.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# bayes-toolbox  

`bayes-toolbox` (aka, Bayesian Statistics Toolbox [BST]) is a Python package for running sophisticated Bayesian analyses in a simple, straight forward manner. 


## Documentation

The documentation for `bayes-toolbox` is hosted [here](https://hyosubkim.github.io/bayes-toolbox/).


## Installation 

[![PyPI version](https://badge.fury.io/py/bayes-toolbox.svg)](https://badge.fury.io/py/bayes-toolbox)

The recommended method of installing bayes-toolbox is with `pip`:
```
pip install bayes_toolbox
```

See the [installation instructions](https://hyosubkim.github.io/bayes-toolbox/getting-started/) in the [documentation](https://hyosubkim.github.io/bayes-toolbox) for more detailed information. 


## Citing bayes-toolbox

If you use `bayes-toolbox` in your work, please cite our Journal of Open Source Software (JOSS) article:

***APA format:***   
Kim, H. E. (2023). bayes-toolbox: A Python package for Bayesian statistics. Journal of Open Source Software, 8(90), 5526. https://doi.org/10.21105/joss.05526

***BibTeX format:***
```
@article{Kim_bayes-toolbox_A_Python_2023,
author = {Kim, Hyosub E.},
doi = {10.21105/joss.05526},
journal = {Journal of Open Source Software},
month = oct,
number = {90},
pages = {5526},
title = {{bayes-toolbox: A Python package for Bayesian statistics}},
url = {https://joss.theoj.org/papers/10.21105/joss.05526},
volume = {8},
year = {2023}
}
```

## License

This work is distributed for free under a [MIT license](https://github.com/hyosubkim/bayes-toolbox/blob/main/LICENSE). 

## Acknowledgments

Thank you to the following people for generously sharing their work and knowledge:
- [John Kruschke](https://jkkweb.sitehost.iu.edu/)
- [Richard McElreath](https://xcelab.net/rm/)
- [Jordi Warmenhoven](https://github.com/JWarmenhoven)
- [PyMC developers](https://github.com/pymc-devs/pymc)
- [ArviZ developers](https://www.arviz.org/en/latest/our_team.html)


## Contributors

See the [CONTRIBUTORS.md](https://github.com/hyosubkim/bayes-toolbox/blob/main/CONTRIBUTORS.md) file for a regularly updated list of contributors. 

